using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Utils.Log;

namespace WLog.GUI
{
    /// <summary>
    /// Log Reader
    /// </summary>
    public partial class fr_LogReader : Form
    {
        #region Variables
        /// <summary>
        /// LogSet of the logs
        /// </summary>
        private LogSet vLogSet = new LogSet();
        /// <summary>
        /// Index of the LogRow to display
        /// </summary>
        private int vIndex = 0;
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor
        /// </summary>
        public fr_LogReader()
        {
            InitializeComponent();
        }
        #endregion

        #region Methods
        /// <summary>
        /// Displays the Indexed LogRow
        /// </summary>
        private void DisplayLogRow()
        {
            this.lbl_Date.Text = vLogSet[this.Index].Date.ToShortDateString() + " [" +
                vLogSet[this.Index].Date.ToLongTimeString()+"]";
            this.tb_Message.Text = vLogSet[this.Index].Message;
            this.lbl_Title.Text = vLogSet[this.Index].Title;
            this.lbl_Type.Text = vLogSet[this.Index].Type.ToString();
            this.Text = "Entry " + (this.Index + 1) + " on " + this.vLogSet.Count;
        }
        #endregion

        #region Events
        /// <summary>
        /// Frame load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_FrameLoad(object sender, EventArgs e)
        {
            this.DisplayLogRow();
        }
        /// <summary>
        /// Click on PREVIOUS
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Previous(object sender, EventArgs e)
        {
            if ((this.Index - 1) < 0)
                this.Index = vLogSet.Count - 1;
            else
                this.Index--;
            DisplayLogRow();
        }
        /// <summary>
        /// Click on NEXT
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btn_Next_Click(object sender, EventArgs e)
        {
            if ((this.Index + 1) >= this.vLogSet.Count)
                this.Index = 0;
            else
                this.Index++;
            DisplayLogRow();
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets or sets the LogSet containing the log entries
        /// </summary>
        public LogSet LogSet
        {
            get { return vLogSet; }
            set { vLogSet = value; }
        }
        /// <summary>
        /// TGets or sets the log entry index to display
        /// </summary>
        /// <exception cref="ArgumentNullException">If there is no log entry list</exception>
        /// <exception cref="ArgumentOutOfRangeException">If the index is negative or bigger than
        /// the logs number</exception>
        public int Index
        {
            get { return vIndex; }
            set
            {
                if (vLogSet == null)
                    throw new ArgumentNullException("There is no list of logs");
                if (value < 0 || value > vLogSet.Count)
                    throw new ArgumentOutOfRangeException("The index is out of the range of the log entries");
                vIndex = value;
            }
        }
        #endregion
    }
}